{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "ATAC-seq 04 quantification - PE",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "Definition narrowPeak file in AutoSql format (used in bedToBigBed)",
                    "type": "File",
                    "id": "#main/as_narrowPeak_file"
                },
                {
                    "default": "hs",
                    "doc": "Effective genome size used by MACS2. It can be numeric or a shortcuts:'hs' for human (2.7e9), 'mm' for mouse (1.87e9), 'ce' for C. elegans (9e7) and 'dm' for fruitfly (1.2e8), Default:hs",
                    "type": "string",
                    "id": "#main/genome_effective_size"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_bam_files"
                },
                {
                    "doc": "Two column tab-delimited file with chromosome size information",
                    "type": "File",
                    "id": "#main/input_genome_sizes"
                },
                {
                    "default": 1,
                    "type": "int",
                    "id": "#main/nthreads"
                }
            ],
            "steps": [
                {
                    "run": "#bedtools-bamtobed.cwl",
                    "scatter": "#main/bedtools_bamtobed/bam",
                    "in": [
                        {
                            "source": "#main/sort-bam-by-name/sorted_file",
                            "id": "#main/bedtools_bamtobed/bam"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/bedtools_bamtobed/bedpe"
                        }
                    ],
                    "out": [
                        "#main/bedtools_bamtobed/output_bedfile"
                    ],
                    "id": "#main/bedtools_bamtobed"
                },
                {
                    "run": "#count-with-output-suffix.cwl",
                    "in": [
                        {
                            "source": "#main/peak-calling/output_peak_file",
                            "id": "#main/count-peaks/input_file"
                        },
                        {
                            "valueFrom": ".peak_count.within_replicate.txt",
                            "id": "#main/count-peaks/output_suffix"
                        }
                    ],
                    "scatter": "#main/count-peaks/input_file",
                    "out": [
                        "#main/count-peaks/output_counts"
                    ],
                    "id": "#main/count-peaks"
                },
                {
                    "run": "#count-with-output-suffix.cwl",
                    "scatter": "#main/count-peaks-unpaired/input_file",
                    "in": [
                        {
                            "source": "#main/peak-calling-unpaired/output_peak_file",
                            "id": "#main/count-peaks-unpaired/input_file"
                        },
                        {
                            "valueFrom": ".peak_count.within_replicate.txt",
                            "id": "#main/count-peaks-unpaired/output_suffix"
                        }
                    ],
                    "out": [
                        "#main/count-peaks-unpaired/output_counts"
                    ],
                    "id": "#main/count-peaks-unpaired"
                },
                {
                    "run": "#count-reads-after-filtering.cwl",
                    "in": [
                        {
                            "source": "#main/peak-calling/output_peak_xls_file",
                            "id": "#main/count-reads-filtered/peak_xls_file"
                        }
                    ],
                    "scatter": "#main/count-reads-filtered/peak_xls_file",
                    "out": [
                        "#main/count-reads-filtered/read_count_file"
                    ],
                    "id": "#main/count-reads-filtered"
                },
                {
                    "run": "#count-reads-after-filtering.cwl",
                    "scatter": "#main/count-reads-filtered-unpaired/peak_xls_file",
                    "in": [
                        {
                            "source": "#main/peak-calling-unpaired/output_peak_xls_file",
                            "id": "#main/count-reads-filtered-unpaired/peak_xls_file"
                        }
                    ],
                    "out": [
                        "#main/count-reads-filtered-unpaired/read_count_file"
                    ],
                    "id": "#main/count-reads-filtered-unpaired"
                },
                {
                    "run": "#samtools-extract-number-mapped-reads.cwl",
                    "scatter": "#main/extract-count-reads-in-peaks/input_bam_file",
                    "in": [
                        {
                            "source": "#main/filter-reads-in-peaks/filtered_file",
                            "id": "#main/extract-count-reads-in-peaks/input_bam_file"
                        },
                        {
                            "valueFrom": ".read_count.within_replicate.txt",
                            "id": "#main/extract-count-reads-in-peaks/output_suffix"
                        }
                    ],
                    "out": [
                        "#main/extract-count-reads-in-peaks/output_read_count"
                    ],
                    "id": "#main/extract-count-reads-in-peaks"
                },
                {
                    "run": "#extract-best-frag-length.cwl",
                    "scatter": "#main/extract-peak-frag-length/input_spp_txt_file",
                    "in": [
                        {
                            "source": "#main/spp/output_spp_cross_corr",
                            "id": "#main/extract-peak-frag-length/input_spp_txt_file"
                        }
                    ],
                    "out": [
                        "#main/extract-peak-frag-length/output_best_frag_length"
                    ],
                    "id": "#main/extract-peak-frag-length"
                },
                {
                    "run": "#samtools-filter-in-bedfile.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/filter-reads-in-peaks/input_bam_file",
                        "#main/filter-reads-in-peaks/input_bedfile"
                    ],
                    "in": [
                        {
                            "source": "#main/input_bam_files",
                            "id": "#main/filter-reads-in-peaks/input_bam_file"
                        },
                        {
                            "source": "#main/peak-calling/output_peak_file",
                            "id": "#main/filter-reads-in-peaks/input_bedfile"
                        }
                    ],
                    "out": [
                        "#main/filter-reads-in-peaks/filtered_file"
                    ],
                    "id": "#main/filter-reads-in-peaks"
                },
                {
                    "run": "#samtools-filter-in-bedfile.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/filter-reads-in-peaks-unpaired/input_bam_file",
                        "#main/filter-reads-in-peaks-unpaired/input_bedfile"
                    ],
                    "in": [
                        {
                            "source": "#main/input_bam_files",
                            "id": "#main/filter-reads-in-peaks-unpaired/input_bam_file"
                        },
                        {
                            "source": "#main/peak-calling-unpaired/output_peak_file",
                            "id": "#main/filter-reads-in-peaks-unpaired/input_bedfile"
                        }
                    ],
                    "out": [
                        "#main/filter-reads-in-peaks-unpaired/filtered_file"
                    ],
                    "id": "#main/filter-reads-in-peaks-unpaired"
                },
                {
                    "run": "#macs2-callpeak.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/peak-calling/treatment"
                    ],
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/peak-calling/bdg"
                        },
                        {
                            "valueFrom": "BAMPE",
                            "id": "#main/peak-calling/format"
                        },
                        {
                            "source": "#main/genome_effective_size",
                            "id": "#main/peak-calling/g"
                        },
                        {
                            "valueFrom": "${return 0.1}",
                            "id": "#main/peak-calling/q"
                        },
                        {
                            "source": "#main/input_bam_files",
                            "valueFrom": "$([self])",
                            "id": "#main/peak-calling/treatment"
                        }
                    ],
                    "out": [
                        "#main/peak-calling/output_peak_file",
                        "#main/peak-calling/output_peak_summits_file",
                        "#main/peak-calling/output_ext_frag_bdg_file",
                        "#main/peak-calling/output_peak_xls_file"
                    ],
                    "id": "#main/peak-calling"
                },
                {
                    "run": "#macs2-callpeak.cwl",
                    "scatter": "#main/peak-calling-unpaired/treatment",
                    "in": [
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/peak-calling-unpaired/bdg"
                        },
                        {
                            "valueFrom": "${return 200}",
                            "id": "#main/peak-calling-unpaired/extsize"
                        },
                        {
                            "valueFrom": "BED",
                            "id": "#main/peak-calling-unpaired/format"
                        },
                        {
                            "source": "#main/genome_effective_size",
                            "id": "#main/peak-calling-unpaired/g"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/peak-calling-unpaired/nomodel"
                        },
                        {
                            "valueFrom": "${return 0.1}",
                            "id": "#main/peak-calling-unpaired/q"
                        },
                        {
                            "valueFrom": "${return -100}",
                            "id": "#main/peak-calling-unpaired/shift"
                        },
                        {
                            "source": "#main/unpair_bedpe/bed",
                            "valueFrom": "$([self])",
                            "id": "#main/peak-calling-unpaired/treatment"
                        }
                    ],
                    "out": [
                        "#main/peak-calling-unpaired/output_peak_file",
                        "#main/peak-calling-unpaired/output_peak_summits_file",
                        "#main/peak-calling-unpaired/output_ext_frag_bdg_file",
                        "#main/peak-calling-unpaired/output_peak_xls_file"
                    ],
                    "id": "#main/peak-calling-unpaired"
                },
                {
                    "run": "#bedToBigBed.cwl",
                    "in": [
                        {
                            "source": "#main/as_narrowPeak_file",
                            "id": "#main/peaks-bed-to-bigbed/as"
                        },
                        {
                            "source": "#main/trunk-peak-score/trunked_scores_peaks",
                            "id": "#main/peaks-bed-to-bigbed/bed"
                        },
                        {
                            "source": "#main/input_genome_sizes",
                            "id": "#main/peaks-bed-to-bigbed/genome_sizes"
                        },
                        {
                            "valueFrom": "bed6+4",
                            "id": "#main/peaks-bed-to-bigbed/type"
                        }
                    ],
                    "scatter": "#main/peaks-bed-to-bigbed/bed",
                    "out": [
                        "#main/peaks-bed-to-bigbed/bigbed"
                    ],
                    "id": "#main/peaks-bed-to-bigbed"
                },
                {
                    "run": "#bedToBigBed.cwl",
                    "in": [
                        {
                            "source": "#main/as_narrowPeak_file",
                            "id": "#main/peaks-bed-to-bigbed-unpaired/as"
                        },
                        {
                            "source": "#main/trunk-peak-score-unpaired/trunked_scores_peaks",
                            "id": "#main/peaks-bed-to-bigbed-unpaired/bed"
                        },
                        {
                            "source": "#main/input_genome_sizes",
                            "id": "#main/peaks-bed-to-bigbed-unpaired/genome_sizes"
                        },
                        {
                            "valueFrom": "bed6+4",
                            "id": "#main/peaks-bed-to-bigbed-unpaired/type"
                        }
                    ],
                    "scatter": "#main/peaks-bed-to-bigbed-unpaired/bed",
                    "out": [
                        "#main/peaks-bed-to-bigbed-unpaired/bigbed"
                    ],
                    "id": "#main/peaks-bed-to-bigbed-unpaired"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "scatter": "#main/sort-bam-by-name/input_file",
                    "in": [
                        {
                            "source": "#main/input_bam_files",
                            "id": "#main/sort-bam-by-name/input_file"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/sort-bam-by-name/n"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/sort-bam-by-name/nthreads"
                        }
                    ],
                    "out": [
                        "#main/sort-bam-by-name/sorted_file"
                    ],
                    "id": "#main/sort-bam-by-name"
                },
                {
                    "run": "#spp.cwl",
                    "scatterMethod": "dotproduct",
                    "scatter": [
                        "#main/spp/input_bam"
                    ],
                    "in": [
                        {
                            "source": "#main/input_bam_files",
                            "id": "#main/spp/input_bam"
                        },
                        {
                            "source": "#main/nthreads",
                            "id": "#main/spp/nthreads"
                        },
                        {
                            "valueFrom": "${return true}",
                            "id": "#main/spp/savp"
                        }
                    ],
                    "out": [
                        "#main/spp/output_spp_cross_corr",
                        "#main/spp/output_spp_cross_corr_plot"
                    ],
                    "id": "#main/spp"
                },
                {
                    "run": "#trunk-peak-score.cwl",
                    "scatter": "#main/trunk-peak-score/peaks",
                    "in": [
                        {
                            "source": "#main/peak-calling/output_peak_file",
                            "id": "#main/trunk-peak-score/peaks"
                        }
                    ],
                    "out": [
                        "#main/trunk-peak-score/trunked_scores_peaks"
                    ],
                    "id": "#main/trunk-peak-score"
                },
                {
                    "run": "#trunk-peak-score.cwl",
                    "in": [
                        {
                            "source": "#main/peak-calling-unpaired/output_peak_file",
                            "id": "#main/trunk-peak-score-unpaired/peaks"
                        }
                    ],
                    "scatter": "#main/trunk-peak-score-unpaired/peaks",
                    "out": [
                        "#main/trunk-peak-score-unpaired/trunked_scores_peaks"
                    ],
                    "id": "#main/trunk-peak-score-unpaired"
                },
                {
                    "run": "#bedpe-to-bed.cwl",
                    "scatter": "#main/unpair_bedpe/bedpe",
                    "in": [
                        {
                            "source": "#main/bedtools_bamtobed/output_bedfile",
                            "id": "#main/unpair_bedpe/bedpe"
                        }
                    ],
                    "out": [
                        "#main/unpair_bedpe/bed"
                    ],
                    "id": "#main/unpair_bedpe"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "doc": "peakshift/phantomPeak extended fragment results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak-calling/output_ext_frag_bdg_file",
                    "id": "#main/output_extended_peak_file"
                },
                {
                    "doc": "Filtered read count reported by MACS2",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/count-reads-filtered/read_count_file",
                    "id": "#main/output_filtered_read_count_file"
                },
                {
                    "doc": "Peaks in bigBed format",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peaks-bed-to-bigbed/bigbed",
                    "id": "#main/output_peak_bigbed_file"
                },
                {
                    "doc": "Peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/count-peaks/output_counts",
                    "id": "#main/output_peak_count_within_replicate"
                },
                {
                    "doc": "peakshift/phantomPeak results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak-calling/output_peak_file",
                    "id": "#main/output_peak_file"
                },
                {
                    "doc": "File containing peak summits",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak-calling/output_peak_summits_file",
                    "id": "#main/output_peak_summits_file"
                },
                {
                    "doc": "Peak calling report file (*_peaks.xls file produced by MACS2)",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak-calling/output_peak_xls_file",
                    "id": "#main/output_peak_xls_file"
                },
                {
                    "doc": "Reads peak counts within replicate",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/extract-count-reads-in-peaks/output_read_count",
                    "id": "#main/output_read_in_peak_count_within_replicate"
                },
                {
                    "doc": "peakshift/phantomPeak results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/spp/output_spp_cross_corr_plot",
                    "id": "#main/output_spp_cross_corr_plot"
                },
                {
                    "doc": "peakshift/phantomPeak results file",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/spp/output_spp_cross_corr",
                    "id": "#main/output_spp_x_cross_corr"
                },
                {
                    "doc": "peakshift/phantomPeak extended fragment results file using each paired mate independently",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak-calling-unpaired/output_ext_frag_bdg_file",
                    "id": "#main/output_unpaired_extended_peak_file"
                },
                {
                    "doc": "Filtered read count reported by MACS2 using each paired mate independently",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/count-reads-filtered-unpaired/read_count_file",
                    "id": "#main/output_unpaired_filtered_read_count_file"
                },
                {
                    "doc": "Peaks in bigBed format using each paired mate independently",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peaks-bed-to-bigbed-unpaired/bigbed",
                    "id": "#main/output_unpaired_peak_bigbed_file"
                },
                {
                    "doc": "Peak counts within replicate using each paired mate independently",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/count-peaks-unpaired/output_counts",
                    "id": "#main/output_unpaired_peak_count_within_replicate"
                },
                {
                    "doc": "peakshift/phantomPeak results file using each paired mate independently",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak-calling-unpaired/output_peak_file",
                    "id": "#main/output_unpaired_peak_file"
                },
                {
                    "doc": "File containing peak summits using each paired mate independently",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak-calling-unpaired/output_peak_summits_file",
                    "id": "#main/output_unpaired_peak_summits_file"
                },
                {
                    "doc": "Peak calling report file (*_peaks.xls file produced by MACS2) using each paired mate independently",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/peak-calling-unpaired/output_peak_xls_file",
                    "id": "#main/output_unpaired_peak_xls_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/bedtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-i"
                    },
                    "doc": "Input BAM file to be converted to BED format",
                    "id": "#bedtools-bamtobed.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bed12"
                    },
                    "doc": "Write \"blocked\" BED format (aka \"BED12\"). Forces -split.\n",
                    "id": "#bedtools-bamtobed.cwl/bed12"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bedpe"
                    },
                    "doc": "Write BEDPE format.\n- Requires BAM to be grouped or sorted by query.\n",
                    "id": "#bedtools-bamtobed.cwl/bedpe"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-cigar"
                    },
                    "doc": "Add the CIGAR string to the BED entry as a 7th column.\n",
                    "id": "#bedtools-bamtobed.cwl/cigar"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-color"
                    },
                    "doc": "An R,G,B string for the color used with BED12 format.\nDefault is (255,0,0).\n",
                    "id": "#bedtools-bamtobed.cwl/color"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ed"
                    },
                    "doc": "Use BAM edit distance (NM tag) for BED score.\n- Default for BED is to use mapping quality.\n- Default for BEDPE is to use the minimum of\nthe two mapping qualities for the pair.\n- When -ed is used with -bedpe, the total edit\ndistance from the two mates is reported.\n",
                    "id": "#bedtools-bamtobed.cwl/ed"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-mate1"
                    },
                    "doc": "When writing BEDPE (-bedpe) format, \nalways report mate one as the first BEDPE \"block\".\n",
                    "id": "#bedtools-bamtobed.cwl/mate1"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    },
                    "doc": "Report \"split\" BAM alignments as separate BED entries.\nSplits only on N CIGAR operations.\n",
                    "id": "#bedtools-bamtobed.cwl/split"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-splitD"
                    },
                    "doc": "Split alignments based on N and D CIGAR operators.\nForces -split.\n",
                    "id": "#bedtools-bamtobed.cwl/splitD"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-tag"
                    },
                    "doc": "Use other NUMERIC BAM alignment tag for BED score.\n- Default for BED is to use mapping quality.\nDisallowed with BEDPE output.\n",
                    "id": "#bedtools-bamtobed.cwl/tag"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bed')"
                    },
                    "id": "#bedtools-bamtobed.cwl/output_bedfile"
                }
            ],
            "baseCommand": [
                "bedtools",
                "bamtobed"
            ],
            "stdout": "$(inputs.bam.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + '.bed')",
            "id": "#bedtools-bamtobed.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1000
                    },
                    "doc": "Aligned file to be sorted with samtools",
                    "id": "#samtools-sort.cwl/input_file"
                },
                {
                    "type": "boolean",
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-n"
                    },
                    "doc": "Sort by read name",
                    "id": "#samtools-sort.cwl/n"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "Number of threads used in sorting",
                    "id": "#samtools-sort.cwl/nthreads"
                },
                {
                    "type": "string",
                    "default": ".sorted.bam",
                    "doc": "suffix of the transformed SAM/BAM file (including extension, e.g. .filtered.sam)",
                    "id": "#samtools-sort.cwl/suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + inputs.suffix)"
                    },
                    "doc": "Sorted aligned file",
                    "id": "#samtools-sort.cwl/sorted_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + inputs.suffix)",
            "id": "#samtools-sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Un-pack a BEDPE concatenating both mates so that they are treated independently",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bedpe-to-bed.cwl/bedpe"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bedpe.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '').replace(/([_\\.]?sorted)*$/, '.unpaired.bed'))"
                    },
                    "id": "#bedpe-to-bed.cwl/bed"
                }
            ],
            "baseCommand": "bedpe-to-bed.sh",
            "stdout": "$(inputs.bedpe.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '').replace(/([_\\.]?sorted)*$/, '.unpaired.bed'))",
            "id": "#bedpe-to-bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Count number of dedup-ed reads used in peak calling",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count-reads-after-filtering.cwl/peak_xls_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.peak_xls_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\_peaks\\.xls$/, '_read_count.txt'))"
                    },
                    "id": "#count-reads-after-filtering.cwl/read_count_file"
                }
            ],
            "baseCommand": "count-filtered-reads-macs2.sh",
            "stdout": "$(inputs.peak_xls_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\_peaks\\.xls$/, '_read_count.txt'))",
            "id": "#count-reads-after-filtering.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/macs2",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--SPMR"
                    },
                    "doc": "If True, MACS will save signal per million reads for fragment pileup profiles. Require --bdg to be set. Default: False ",
                    "id": "#macs2-callpeak.cwl/SPMR"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bdg"
                    },
                    "doc": "Whether or not to save extended fragment pileup, and local lambda tracks (two files) at every bp into a bedGraph file. DEFAULT: True",
                    "id": "#macs2-callpeak.cwl/bdg"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--broad"
                    },
                    "doc": "If set, MACS will try to call broad peaks by linking nearby highly enriched regions. The linking region is controlled by another cutoff through --linking-cutoff. The maximum linking region length is 4 times of d from MACS. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/broad"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--broad-cutoff"
                    },
                    "doc": "BROADCUTOFF\nCutoff for broad region. This option is not available\nunless --broad is set. If -p is set, this is a pvalue\ncutoff, otherwise, it's a qvalue cutoff. DEFAULT: 0.1\n",
                    "id": "#macs2-callpeak.cwl/broad-cutoff"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--buffer-size"
                    },
                    "doc": "BUFFER_SIZE\nBuffer size for incrementally increasing internal\narray size to store reads alignment information. In\nmost cases, you don't have to change this parameter.\nHowever, if there are large number of\nchromosomes/contigs/scaffolds in your alignment, it's\nrecommended to specify a smaller buffer size in order\nto decrease memory usage (but it will take longer time\nto read alignment files). Minimum memory requested for\nreading an alignment file is about # of CHROMOSOME *\nBUFFER_SIZE * 2 Bytes. DEFAULT: 100000\n",
                    "id": "#macs2-callpeak.cwl/buffer-size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bw"
                    },
                    "doc": "BW               Band width for picking regions to compute fragment\nsize. This value is only used while building the\nshifting model. DEFAULT: 300\n",
                    "id": "#macs2-callpeak.cwl/bw"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--call-summits"
                    },
                    "doc": "If set, MACS will use a more sophisticated signal processing approach to find subpeak summits in each enriched peak region. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/call-summits"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--control"
                    },
                    "doc": "Control sample file.",
                    "id": "#macs2-callpeak.cwl/control"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--cutoff-analysis"
                    },
                    "doc": "While set, MACS2 will analyze number or total length of peaks that can be called by different p-value cutoff then output a summary table to help user decide a better cutoff. The table will be saved in NAME_cutoff_analysis.txt file. Note, minlen and maxgap may affect the results. WARNING: May take ~30 folds longer time to finish. DEFAULT: False Post-processing options: ",
                    "id": "#macs2-callpeak.cwl/cutoff-analysis"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--down-sample"
                    },
                    "doc": "When set, random sampling method will scale down the bigger sample. By default, MACS uses linear scaling. Warning: This option will make your result unstable and irreproducible since each time, random reads would be selected. Consider to use 'randsample' script instead. <not implmented>If used together with --SPMR, 1 million unique reads will be randomly picked.</not implemented> Caution: due to the implementation, the final number of selected reads may not be as you expected! DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/down-sample"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--extsize"
                    },
                    "doc": "The arbitrary extension size in bp. When nomodel is  true, MACS will use this value as fragment size to  extend each read towards 3' end, then pile them up.  It's exactly twice the number of obsolete SHIFTSIZE.  In previous language, each read is moved 5'->3'  direction to middle of fragment by 1/2 d, then  extended to both direction with 1/2 d. This is  equivalent to say each read is extended towards 5'->3'  into a d size fragment. DEFAULT: 200. EXTSIZE and  SHIFT can be combined when necessary. Check SHIFT  option.",
                    "id": "#macs2-callpeak.cwl/extsize"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fe-cutoff"
                    },
                    "doc": "FECUTOFF  When set, the value will be used to filter out peaks\nwith low fold-enrichment. Note, MACS2 use 1.0 as\npseudocount while calculating fold-enrichment.\nDEFAULT: 1.0\n",
                    "id": "#macs2-callpeak.cwl/fe-cutoff"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--fix-bimodal"
                    },
                    "doc": "Whether turn on the auto pair model process. If set, when MACS failed to build paired model, it will use the nomodel settings, the --exsize parameter to extend each tags towards 3' direction. Not to use this automate fixation is a default behavior now. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/fix-bimodal"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "-f {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE}, --format {AUTO,BAM,SAM,BED,ELAND,ELANDMULTI,ELANDEXPORT,BOWTIE,BAMPE} Format of tag file, \"AUTO\", \"BED\" or \"ELAND\" or \"ELANDMULTI\" or \"ELANDEXPORT\" or \"SAM\" or \"BAM\" or \"BOWTIE\" or \"BAMPE\". The default AUTO option will let MACS decide which format the file is. Note that MACS can't detect \"BAMPE\" or \"BEDPE\" format with \"AUTO\", and you have to implicitly specify the format for \"BAMPE\" and \"BEDPE\". DEFAULT: \"AUTO\".",
                    "id": "#macs2-callpeak.cwl/format"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-g"
                    },
                    "doc": "Effective genome size. It can be 1.0e+9 or 1000000000,  or shortcuts:'hs' for human (2.7e9), 'mm' for mouse  (1.87e9), 'ce' for C. elegans (9e7) and 'dm' for  fruitfly (1.2e8), Default:hs.",
                    "id": "#macs2-callpeak.cwl/g"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--keep-dup"
                    },
                    "doc": "KEEPDUPLICATES\nIt controls the MACS behavior towards duplicate tags\nat the exact same location -- the same coordination\nand the same strand. The 'auto' option makes MACS\ncalculate the maximum tags at the exact same location\nbased on binomal distribution using 1e-5 as pvalue\ncutoff; and the 'all' option keeps every tags. If an\ninteger is given, at most this number of tags will be\nkept at the same location. The default is to keep one\ntag at the same location. Default: 1\n",
                    "id": "#macs2-callpeak.cwl/keep-dup"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--llocal"
                    },
                    "doc": "LARGELOCAL   The large nearby region in basepairs to calculate\ndynamic lambda. This is used to capture the surround\nbias. If you set this to 0, MACS will skip llocal\nlambda calculation. *Note* that MACS will always\nperform a d-size local lambda calculation. The final\nlocal bias should be the maximum of the lambda value\nfrom d, slocal, and llocal size windows. DEFAULT:\n10000.\n",
                    "id": "#macs2-callpeak.cwl/llocal"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-m"
                    },
                    "doc": "MFOLD MFOLD, --mfold MFOLD MFOLD\nSelect the regions within MFOLD range of high-\nconfidence enrichment ratio against background to\nbuild model. Fold-enrichment in regions must be lower\nthan upper limit, and higher than the lower limit. Use\nas \"-m 10 30\". DEFAULT:5 50\n",
                    "id": "#macs2-callpeak.cwl/m"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--nolambda"
                    },
                    "doc": "If True, MACS will use fixed background lambda as local lambda for every peak region. Normally, MACS calculates a dynamic local lambda to reflect the local bias due to potential chromatin structure. ",
                    "id": "#macs2-callpeak.cwl/nolambda"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--nomodel"
                    },
                    "doc": "\t Whether or not to build the shifting model. If True,  MACS will not build model. by default it means  shifting size = 100, try to set extsize to change it.  DEFAULT: False",
                    "id": "#macs2-callpeak.cwl/nomodel"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-p"
                    },
                    "doc": "Pvalue cutoff for peak detection. DEFAULT: not set.  -q, and -p are mutually exclusive. If pvalue cutoff is  set, qvalue will not be calculated and reported as -1  in the final .xls file..",
                    "id": "#macs2-callpeak.cwl/p"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "Minimum FDR (q-value) cutoff for peak detection. DEFAULT: 0.05. -q, and -p are mutually exclusive.",
                    "id": "#macs2-callpeak.cwl/q"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--ratio"
                    },
                    "doc": "RATIO         When set, use a custom scaling ratio of ChIP/control\n(e.g. calculated using NCIS) for linear scaling.\nDEFAULT: ingore\n",
                    "id": "#macs2-callpeak.cwl/ratio"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "TSIZE, --tsize TSIZE\nTag size. This will overide the auto detected tag\nsize. DEFAULT: Not set\n",
                    "id": "#macs2-callpeak.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--seed"
                    },
                    "doc": "SEED           Set the random seed while down sampling data. Must be\na non-negative integer in order to be effective.\nDEFAULT: not set\n",
                    "id": "#macs2-callpeak.cwl/seed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--shift"
                    },
                    "doc": "(NOT the legacy --shiftsize option!) The arbitrary shift in bp. Use discretion while setting it other than default value. When NOMODEL is set, MACS will use this value to move cutting ends (5') towards 5'->3' direction then apply EXTSIZE to extend them to fragments. When this value is negative, ends will be moved toward 3'->5' direction. Recommended to keep it as default 0 for ChIP-Seq datasets, or -1 * half of EXTSIZE together with EXTSIZE option for detecting enriched cutting loci such as certain DNAseI-Seq datasets. Note, you can't set values other than 0 if format is BAMPE for paired-end data. DEFAULT: 0.",
                    "id": "#macs2-callpeak.cwl/shift"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--slocal"
                    },
                    "doc": "SMALLLOCAL   The small nearby region in basepairs to calculate\ndynamic lambda. This is used to capture the bias near\nthe peak summit region. Invalid if there is no control\ndata. If you set this to 0, MACS will skip slocal\nlambda calculation. *Note* that MACS will always\nperform a d-size local lambda calculation. The final\nlocal bias should be the maximum of the lambda value\nfrom d, slocal, and llocal size windows. DEFAULT: 1000\n",
                    "id": "#macs2-callpeak.cwl/slocal"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--to-large"
                    },
                    "doc": "When set, scale the small sample up to the bigger sample. By default, the bigger dataset will be scaled down towards the smaller dataset, which will lead to smaller p/qvalues and more specific results. Keep in mind that scaling down will bring down background noise more. DEFAULT: False ",
                    "id": "#macs2-callpeak.cwl/to-large"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--trackline"
                    },
                    "doc": "Tells MACS to include trackline with bedGraph files. To include this trackline while displaying bedGraph at UCSC genome browser, can show name and description of the file as well. However my suggestion is to convert bedGraph to bigWig, then show the smaller and faster binary bigWig file at UCSC genome browser, as well as downstream analysis. Require --bdg to be set. Default: Not include trackline. ",
                    "id": "#macs2-callpeak.cwl/trackline"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--treatment"
                    },
                    "doc": "Treatment sample file(s). If multiple files are given as -t A B C, then they will all be read and pooled together. IMPORTANT: the first sample will be used as the outputs basename.",
                    "id": "#macs2-callpeak.cwl/treatment"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--verbose"
                    },
                    "doc": "VERBOSE_LEVEL     Set verbose level of runtime message. 0: only show\ncritical message, 1: show additional warning message,\n2: show process information, 3: show debug messages.\nDEFAULT:2\n",
                    "id": "#macs2-callpeak.cwl/verbose"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_treat_pileup.bdg')"
                    },
                    "doc": "Bedgraph with extended fragment pileup.",
                    "id": "#macs2-callpeak.cwl/output_ext_frag_bdg_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_peaks.*Peak')",
                        "outputEval": "$(self[0])"
                    },
                    "doc": "Peak calling output file in narrowPeak|broadPeak format.",
                    "id": "#macs2-callpeak.cwl/output_peak_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_summits.bed')"
                    },
                    "doc": "Peaks summits bedfile.",
                    "id": "#macs2-callpeak.cwl/output_peak_summits_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '_peaks.xls')"
                    },
                    "doc": "Peaks information/report file.",
                    "id": "#macs2-callpeak.cwl/output_peak_xls_file"
                }
            ],
            "baseCommand": [
                "macs2",
                "callpeak"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.treatment[0].path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, ''))",
                    "prefix": "-n",
                    "position": 1
                }
            ],
            "id": "#macs2-callpeak.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extract mapped reads from BAM file using Samtools flagstat command",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Aligned BAM file to filter",
                    "id": "#samtools-extract-number-mapped-reads.cwl/input_bam_file"
                },
                {
                    "type": "string",
                    "id": "#samtools-extract-number-mapped-reads.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)"
                    },
                    "doc": "Samtools Flagstat report file",
                    "id": "#samtools-extract-number-mapped-reads.cwl/output_read_count"
                }
            ],
            "baseCommand": [
                "samtools",
                "flagstat"
            ],
            "arguments": [
                {
                    "valueFrom": " | head -n1 | cut -f 1 -d ' '",
                    "position": 10000,
                    "shellQuote": false
                }
            ],
            "stdout": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)",
            "id": "#samtools-extract-number-mapped-reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Filter BAM file to only include reads overlapping with a BED file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/samtools:1.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Aligned BAM file to filter",
                    "id": "#samtools-filter-in-bedfile.cwl/input_bam_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-L"
                    },
                    "doc": "Bedfile used to only include reads overlapping this BED FILE",
                    "id": "#samtools-filter-in-bedfile.cwl/input_bedfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '') + '.in_peaks.bam')"
                    },
                    "doc": "Filtered aligned BAM file by BED coordinates file",
                    "id": "#samtools-filter-in-bedfile.cwl/filtered_file"
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-b",
                "-h"
            ],
            "stdout": "$(inputs.input_bam_file.path.replace(/^.*[\\\\\\/]/, '') + '.in_peaks.bam')",
            "id": "#samtools-filter-in-bedfile.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "\"bedToBigBed v. 2.7 - Convert bed file to bigBed. (BigBed version: 4)\nusage:\n   bedToBigBed in.bed chrom.sizes out.bb\nWhere in.bed is in one of the ascii bed formats, but not including track lines\nand chrom.sizes is two column: <chromosome name> <size in bases>\nand out.bb is the output indexed big bed file.\nUse the script: fetchChromSizes to obtain the actual chrom.sizes information\nfrom UCSC, please do not make up a chrom sizes from your own information.\nThe in.bed file must be sorted by chromosome,start,\n  to sort a bed file, use the unix sort command:\n     sort -k1,1 -k2,2n unsorted.bed > sorted.bed\"\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dleehr/docker-hubutils",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-as=",
                        "separate": false
                    },
                    "doc": "-as=fields.as - If you have non-standard \"bedPlus\" fields, it's great to put a definition\n                 of each field in a row in AutoSql format here.1)\n",
                    "id": "#bedToBigBed.cwl/as"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Input bed file",
                    "id": "#bedToBigBed.cwl/bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-blockSize=",
                        "separate": false
                    },
                    "doc": "-blockSize=N - Number of items to bundle in r-tree.  Default 256\n",
                    "id": "#bedToBigBed.cwl/blockSize"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-extraIndex=",
                        "itemSeparator": ","
                    },
                    "doc": "-extraIndex=fieldList - If set, make an index on each field in a comma separated list\n   extraIndex=name and extraIndex=name,id are commonly used.\n",
                    "id": "#bedToBigBed.cwl/extraIndex"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "genome_sizes is two column: <chromosome name> <size in bases>.\n",
                    "id": "#bedToBigBed.cwl/genome_sizes"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-itemsPerSlot=",
                        "separate": false
                    },
                    "doc": "-itemsPerSlot=N - Number of data points bundled at lowest level. Default 512\n",
                    "id": "#bedToBigBed.cwl/itemsPerSlot"
                },
                {
                    "type": "string",
                    "default": ".bb",
                    "id": "#bedToBigBed.cwl/output_suffix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-tab - If set, expect fields to be tab separated, normally expects white space separator.\n",
                    "id": "#bedToBigBed.cwl/tab"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-type=",
                        "separate": false
                    },
                    "doc": "-type=bedN[+[P]] :\n                N is between 3 and 15,\n                optional (+) if extra \"bedPlus\" fields,\n                optional P specifies the number of extra fields. Not required, but preferred.\n                Examples: -type=bed6 or -type=bed6+ or -type=bed6+3\n                (see http://genome.ucsc.edu/FAQ/FAQformat.html#format1)\n",
                    "id": "#bedToBigBed.cwl/type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-unc - If set, do not use compression.\n",
                    "id": "#bedToBigBed.cwl/unc"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bed.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)"
                    },
                    "id": "#bedToBigBed.cwl/bigbed"
                }
            ],
            "baseCommand": "bedToBigBed",
            "arguments": [
                {
                    "valueFrom": "$(inputs.bed.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, \"\") + inputs.output_suffix)",
                    "position": 4
                }
            ],
            "id": "#bedToBigBed.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Extracts best fragment length from SPP output text file",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#extract-best-frag-length.cwl/input_spp_txt_file"
                }
            ],
            "outputs": [
                {
                    "type": "float",
                    "outputBinding": {
                        "glob": "best_frag_length",
                        "loadContents": true,
                        "outputEval": "$(Number(self[0].contents.replace('\\n', '')))"
                    },
                    "id": "#extract-best-frag-length.cwl/output_best_frag_length"
                }
            ],
            "baseCommand": "extract-best-frag-length.sh",
            "stdout": "best_frag_length",
            "id": "#extract-best-frag-length.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "dukegcb/spp",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-i=",
                        "separate": false
                    },
                    "doc": "<Input_alignFile>, full path and name (or URL) of tagAlign/BAM file (can be gzipped) (FILE EXTENSION MUST BE tagAlign.gz, tagAlign, bam or bam.gz)",
                    "id": "#spp.cwl/control_bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "-fdr=",
                        "separate": false
                    },
                    "doc": "-fdr=<falseDisoveryRate> , false discovery rate threshold for peak calling",
                    "id": "#spp.cwl/fdr"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-filtchr=",
                        "separate": false
                    },
                    "doc": "-filtchr=<chrnamePattern> , Pattern to use to remove tags that map to specific chromosomes e.g. _ will remove all tags that map to chromosomes with _ in their name",
                    "id": "#spp.cwl/filtchr"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-c=",
                        "separate": false
                    },
                    "doc": "<ChIP_alignFile>, full path and name (or URL) of tagAlign/BAM file (can be gzipped)(FILE EXTENSION MUST BE tagAlign.gz, tagAlign, bam or bam.gz)",
                    "id": "#spp.cwl/input_bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-npeak=",
                        "separate": false
                    },
                    "doc": "-npeak=<numPeaks>, threshold on number of peaks to call",
                    "id": "#spp.cwl/npeak"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p=",
                        "separate": false
                    },
                    "doc": "-p=<nodes> , number of parallel processing nodes, default=0",
                    "id": "#spp.cwl/nthreads"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "-rf"
                    },
                    "doc": "overwrite (force remove) output files in case they exist. Default: true",
                    "id": "#spp.cwl/rf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-s=",
                        "separate": false
                    },
                    "doc": "-s=<min>:<step>:<max> , strand shifts at which cross-correlation is evaluated, default=-500:5:1500",
                    "id": "#spp.cwl/s"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savd=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.Rdata\"; return null}"
                    },
                    "doc": "-savd=<rdatafile> OR -savd, save Rdata file",
                    "id": "#spp.cwl/savd"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savn=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.narrowPeak\"; return null}"
                    },
                    "doc": "-savn=<narrowpeakfilename> OR -savn NarrowPeak file name (fixed width peaks)",
                    "id": "#spp.cwl/savn"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savp=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.pdf\"; return null}"
                    },
                    "doc": "save cross-correlation plot",
                    "id": "#spp.cwl/savp"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if (self) return \"-savr=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.regionPeak\"; return null}"
                    },
                    "doc": "-savr=<regionpeakfilename> OR -savr RegionPeak file name (variable width peaks with regions of enrichment)",
                    "id": "#spp.cwl/savr"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-speak=",
                        "separate": false
                    },
                    "doc": "-speak=<strPeak>, user-defined cross-correlation peak strandshift",
                    "id": "#spp.cwl/speak"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-x=",
                        "separate": false
                    },
                    "doc": "-x=<min>:<max>, strand shifts to exclude (This is mainly to avoid region around phantom peak) default=10:(readlen+10)",
                    "id": "#spp.cwl/x"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.txt\")"
                    },
                    "doc": "peakshift/phantomPeak results summary file",
                    "id": "#spp.cwl/output_spp_cross_corr"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.pdf\")"
                    },
                    "doc": "peakshift/phantomPeak results summary plot",
                    "id": "#spp.cwl/output_spp_cross_corr_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.narrowPeak\")"
                    },
                    "doc": "narrowPeak output file",
                    "id": "#spp.cwl/output_spp_narrow_peak"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.Rdata\")"
                    },
                    "doc": "Rdata file from the run_spp.R run",
                    "id": "#spp.cwl/output_spp_rdata"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp.regionPeak\")"
                    },
                    "doc": "regionPeak output file",
                    "id": "#spp.cwl/output_spp_region_peak"
                }
            ],
            "baseCommand": "run_spp.R",
            "arguments": [
                {
                    "valueFrom": "$(\"-out=\" + inputs.input_bam.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".spp_cross_corr.txt\")"
                },
                {
                    "valueFrom": "$(\"-tmpdir=\"+runtime.tmpdir)",
                    "shellQuote": false
                }
            ],
            "id": "#spp.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Counts lines in a file and returns a suffixed file with that number",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#count-with-output-suffix.cwl/input_file"
                },
                {
                    "type": "string",
                    "default": ".count",
                    "id": "#count-with-output-suffix.cwl/output_suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '') + inputs.output_suffix)"
                    },
                    "id": "#count-with-output-suffix.cwl/output_counts"
                }
            ],
            "baseCommand": [
                "wc",
                "-l"
            ],
            "stdin": "$(inputs.input_file.path)",
            "stdout": "$(inputs.input_file.path.replace(/^.*[\\\\\\/]/, '') + inputs.output_suffix)",
            "id": "#count-with-output-suffix.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Trunk scores in ENCODE bed6+4 files",
            "hints": [
                {
                    "dockerPull": "reddylab/workflow-utils:ggr",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10000
                    },
                    "id": "#trunk-peak-score.cwl/peaks"
                },
                {
                    "type": "string",
                    "default": "\\t",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-F"
                    },
                    "id": "#trunk-peak-score.cwl/sep"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.peaks.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.([^/.]+)$/, \"\\.trunked_scores\\.$1\"))"
                    },
                    "id": "#trunk-peak-score.cwl/trunked_scores_peaks"
                }
            ],
            "baseCommand": "awk",
            "arguments": [
                {
                    "valueFrom": "BEGIN{OFS=FS}$5>1000{$5=1000}{print}",
                    "position": 3
                }
            ],
            "stdout": "$(inputs.peaks.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.([^/.]+)$/, \"\\.trunked_scores\\.$1\"))",
            "id": "#trunk-peak-score.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
